@@ -7,7 +7,6 @@
 from functools import cached_property
 from os import X_OK, access, chdir, getenv
 from pathlib import Path
-import re
 from shutil import which
 from subprocess import run
 from sys import exit as sys_exit
@@ -36,7 +35,7 @@ class Dotfiles:
         """
         self.bare_repo: Path = self._resolve_repo_location(local_bare_repo)
         self.work_tree: Path = self._resolve_work_tree_location(work_tree)
-        self._git_base = [
+        self._git_base: List[str] = [
             "git",
             f"--git-dir={self.bare_repo}",
             f"--work-tree={self.work_tree}",
@@ -166,12 +165,9 @@ class Dotfiles:
 
     def restore(self) -> List[str]:
         """Interactively choose files to remove from the staging area."""
-        restorables = sorted(
-            list(set(self.modified_staged + self.deleted_staged + self.adds_staged))
-        )
-        if restorables:
+        if self.restorables:
             restores = fzf(
-                restorables,
+                self.restorables,
                 prompt="Choose changes to remove from staging area: ",
                 multi=True,
                 preview=f"{self._git_str} diff --color --minimal HEAD -- " + "{}",
@@ -186,6 +182,26 @@ class Dotfiles:
             self.show_status()
             sys_exit("\nNo staged changes to restore.")
 
+    def discard_changes(self) -> List[str]:
+        """Discard changes from file(s) in the working directory."""
+        unstaged = self.modified_unstaged
+        if unstaged:
+            discards = fzf(
+                unstaged,
+                prompt="Choose changes to discard: ",
+                multi=True,
+                preview=f"{self._git_str} diff --color --minimal HEAD -- " + "{}",
+            )
+            if discards is None:
+                sys_exit("No selection made. No changes will be discarded.")
+            else:
+                run(self._git_base + ["restore", "--"] + discards)
+                self.freshen()
+                return discards
+        else:
+            self.show_status()
+            sys_exit("\nNo unstaged changes to discard.")
+
     def make_tar(self) -> Path:
         """Make tarball of dotfiles @ self.work_tree / 'dotfiles.tar.gz'."""
         # TODO: incorporate a 'privatemask' feature
@@ -251,15 +267,7 @@ class Dotfiles:
 
     @property
     def renames(self) -> List[str]:
-        if len(self.short_status) == 0:
-            return []
-        else:
-            rename_lines = [l for l in self.short_status if l[0] == "R"]
-            if len(rename_lines) > 0:
-                rename_files = [f.split(" -> ")[1] for f in rename_lines]
-                return rename_files
-            else:
-                return []
+        return [line.split(" -> ")[1] for line in self.short_status if line[0] == "R"]
 
     @cached_property
     def list_all(self) -> List[str]:
@@ -302,6 +310,10 @@ class Dotfiles:
             del self.executables
         except AttributeError:
             pass
+        try:
+            del self.restorables
+        except AttributeError:
+            pass
 
     @property
     def deleted_staged(self) -> List[str]:
@@ -316,10 +328,16 @@ class Dotfiles:
     @property
     def modified_unstaged(self) -> List[str]:
         """Returns all files with unstaged modifications or Deletions."""
+        # TODO: what about "MM " files? Modified staged changes + unstages mods
         mods = [line[3:] for line in self.short_status if line[:2] in [" M", " D"]]
         renamed_mods = [s.split(" -> ")[1] for s in self.short_status if s[:2] == "RM"]
         return sorted(renamed_mods + mods)
 
+    @cached_property
+    def restorables(self) -> List[str]:
+        """Returns all files which could be affected by `git restore --staged`."""
+        return sorted(self.modified_staged + self.deleted_staged + self.adds_staged)
+
     @cached_property
     def _git_str(self) -> str:
         """String representation of _git_base command."""
